@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2011 Bastian Kleineidam
+# Copyright (C) 2000-2012 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -53,10 +53,6 @@ def urljoin (parent, url, scheme):
     """
     if url.startswith(scheme+":"):
         return url
-    # work around a Python 2.6/3.1 bug cutting off characters when the URL
-    # begins with semicolon
-    if url.startswith(';'):
-        url = "./%s" % url
     return urlparse.urljoin(parent, url)
 
 
