@@ -188,10 +188,6 @@ class HttpCookie (object):
             return scheme == "https"
         return True
 
-    def client_header_name (self):
-        """Return "Cookie" as client header name."""
-        return "Cookie"
-
     def set_attribute (self, key, value):
         """Helper method to set attribute values. Called when parsing
         cookie data.
@@ -228,7 +224,7 @@ class HttpCookie (object):
 
     def parse (self, text, patt=CookiePattern):
         """Parse cookie data."""
-        text = strformat.ascii_safe(text)
+        text = strformat.ascii_safe(text.rstrip('\r\n'))
         # reset values
         self.name = None
         self.value = None
@@ -305,12 +301,6 @@ class HttpCookie (object):
                   for k, v in self.attributes.items() if k != "version"])
         return "; ".join(parts)
 
-    def __eq__ (self, other):
-        """Compare equality of cookie."""
-        return isinstance(other, HttpCookie) and \
-               self.server_header_value() == other.server_header_value()
-
-
 class NetscapeCookie (HttpCookie):
     """Parses RFC 2109 (Netscape) cookies."""
 
@@ -323,6 +313,23 @@ class NetscapeCookie (HttpCookie):
         """Return "Set-Cookie" as server header name."""
         return "Set-Cookie"
 
+    def __eq__ (self, other):
+        """Compare equality of cookie."""
+        return (isinstance(other, NetscapeCookie) and
+            self.name.lower() == other.name.lower() and
+            self.attributes['domain'] == other.attributes['domain'] and
+            self.attributes['path'] == other.attributes['path'])
+
+    def __hash__ (self):
+        """Cookie hash value"""
+        data = (
+          self.name.lower(),
+          self.attributes['domain'],
+          self.attributes['path'],
+        )
+        return hash(data)
+
+
 
 class Rfc2965Cookie (HttpCookie):
     """Parses RFC 2965 cookies."""
@@ -349,6 +356,23 @@ class Rfc2965Cookie (HttpCookie):
             return quote(value, LegalChars="")
         return quote(value)
 
+    def __eq__ (self, other):
+        """Compare equality of cookie."""
+        return (isinstance(other, Rfc2965Cookie) and
+            self.name.lower() == other.name.lower() and
+            self.attributes['domain'].lower() ==
+                other.attributes['domain'].lower() and
+            self.attributes['path'] == other.attributes['path'])
+
+    def __hash__ (self):
+        """Cookie hash value"""
+        data = (
+          self.name.lower(),
+          self.attributes['domain'].lower(),
+          self.attributes['path'],
+        )
+        return hash(data)
+
 
 def from_file (filename):
     """Parse cookie data from a text file in HTTP header format.
