@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2004-2011 Bastian Kleineidam
+# Copyright (C) 2004-2012 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -59,12 +59,6 @@ class TestUrl (unittest.TestCase):
         nurl = "http://server/cskin.zip"
         self.assertEqual(linkcheck.url.url_quote(url_norm(url)), nurl)
 
-    def test_stripsite (self):
-        stripsite = linkcheck.url.stripsite
-        url = "http://example.org/a/b/c"
-        self.assertEqual(stripsite(url)[0], "example.org")
-        self.assertEqual(stripsite(url)[1], "/a/b/c")
-
     def test_safe_patterns (self):
         is_safe_host = linkcheck.url.is_safe_host
         safe_host_pattern = linkcheck.url.safe_host_pattern
